# Overview
IncantoOS Is a wrapper related to OS functions that can made into a smaller faster function

# Usage
IncantoOS Wasnt intended for other people to use it use at your own caution

# Notes
I will try to keep up with the documentation of IncantoOS even though it wasnt meant for public use.

# Discresion
I am not the best coder so do not expect IncantoOS to work properly. If a bug is found you can report it to me via the github.

# Documentation

Prints the current system time.
```py
    incantoos.nowtime()
```

Adds two string values together.
```py
    incantoos.addstr(one, two)
```